@@ -1,4 +1,4 @@
-# Copyright 2015-2017 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,7 +38,7 @@ from yapf.yapflib import py3compat
 from yapf.yapflib import style
 from yapf.yapflib import yapf_api
 
-__version__ = '0.20.0'
+__version__ = '0.22.0'
 
 
 def main(argv):
@@ -49,7 +49,8 @@ def main(argv):
       in argv[0]).
 
   Returns:
-    0 if there were no changes, non-zero otherwise.
+    Zero on successful program termination, non-zero otherwise.
+    With --diff: zero if there were no changes, non-zero otherwise.
 
   Raises:
     YapfError: if none of the supplied files were Python files.
@@ -99,9 +100,10 @@ def main(argv):
       action='store',
       help=('specify formatting style: either a style name (for example "pep8" '
             'or "google"), or the name of a file with style settings. The '
-            'default is pep8 unless a %s or %s file located in one of the '
-            'parent directories of the source file (or current directory for '
-            'stdin)' % (style.LOCAL_STYLE, style.SETUP_CONFIG)))
+            'default is pep8 unless a %s or %s file located in the same '
+            'directory as the source or one of its parent directories '
+            '(for stdin, the current directory is used).' %
+            (style.LOCAL_STYLE, style.SETUP_CONFIG)))
   parser.add_argument(
       '--style-help',
       action='store_true',
@@ -132,8 +134,12 @@ def main(argv):
     print('yapf {}'.format(__version__))
     return 0
 
+  style_config = args.style
+
   if args.style_help:
-    style.SetGlobalStyle(style.CreateStyleFromConfig(args.style))
+    if style_config is None and not args.no_local_style:
+      style_config = file_resources.GetDefaultStyleForDir(os.getcwd())
+    style.SetGlobalStyle(style.CreateStyleFromConfig(style_config))
     print('[style]')
     for option, docstring in sorted(style.Help().items()):
       for line in docstring.splitlines():
@@ -165,7 +171,6 @@ def main(argv):
       except EOFError:
         break
 
-    style_config = args.style
     if style_config is None and not args.no_local_style:
       style_config = file_resources.GetDefaultStyleForDir(os.getcwd())
 
@@ -203,7 +208,7 @@ def FormatFiles(filenames,
                 no_local_style=False,
                 in_place=False,
                 print_diff=False,
-                verify=True,
+                verify=False,
                 parallel=False,
                 verbose=False):
   """Format a list of files.
@@ -253,7 +258,7 @@ def _FormatFile(filename,
                 no_local_style=False,
                 in_place=False,
                 print_diff=False,
-                verify=True,
+                verify=False,
                 verbose=False):
   if verbose:
     print('Reformatting %s' % filename)
